@@ -123,13 +123,14 @@ class Binarize:
                                    qualifiers=qualifiers)
         return df, binarizer.binarize()
     
-    def __instance_binarize(self, values:Iterable):
+    def __instance_binarize(self, values:Iterable) -> None:
         qualifier_col_name = self.__options['qualifiers']['qualifier_col'] if self.__options['qualifiers']['run'] \
             else None
             
-        return Binarize.binarize(df=self.df, values=values, decision_boundary=self.__decision_boundary,
-                                 active_operator=self.__options['active_operator'],
-                                 qualifier_col_name=qualifier_col_name)
+        self.df, bin_values = Binarize.binarize(df=self.df, values=values, decision_boundary=self.__decision_boundary,
+                                        active_operator=self.__options['active_operator'],
+                                        qualifier_col_name=qualifier_col_name)
+        self.df[self.binarized_col_name] = bin_values
     
     def main(self) -> pd.DataFrame:
         if self.__options['convert_units']['units_col']:
@@ -138,10 +139,9 @@ class Binarize:
             converted_values = self.convert_units(output_units).tolist()
             
             self.df[f'{output_units}_{self.__target_col}'] = converted_values
-            self.df, bin_values = self.binarize(converted_values)
-            self.df[self.binarized_col_name] = bin_values
+            self.binarize(converted_values)
         else:
-            self.df[self.binarized_col_name] = self.binarize(self.df[self.__target_col].tolist())
+            self.binarize(self.df[self.__target_col].tolist())
             
         if self.__options['duplicates']['run']:
             self.df = self.handle_duplicates()
