@@ -7,11 +7,32 @@ import copy
 import naclo
 import stse
 from naclo.UnitConverter import UnitConverter
-from naclo.__asset_loader import bleach_default_model
+from naclo.__asset_loader import bleach_default_model, bleach_warnings
 from naclo.__model_schema import bleach_schema
 
 class Bleach:
-    filter_fragments_methods = ['carbon_count', 'mw', 'atom_count', 'none']
+    structure_types = sorted(['smiles', 'mol'])
+    
+    input_units = [
+        'mixed',
+        '-log(M)',
+        'M',
+        'mM',
+        'µM',
+        'nM'
+    ]
+    
+    output_units = [  # No mixed
+        '-log(M)',
+        'M',
+        'mM',
+        'µM',
+        'nM'
+    ]
+    
+    duplicate_methods = sorted(['average', 'remove', 'keep'])
+    
+    fragment_filters = sorted(['carbon_count', 'mw', 'atom_count', 'none'])
     
     def __init__(self, df:pd.DataFrame, model:dict=bleach_default_model) -> None:  # *
         # Load user options
@@ -20,7 +41,6 @@ class Bleach:
         # Validate model
         bleach_schema.validate(self.model)
 
-        self._recognized_structures = ['smiles', 'mol']
         self._default_cols = {
             'smiles': 'SMILES',
             'mol': 'ROMol',
@@ -75,8 +95,7 @@ class Bleach:
         '''Drops NA along declared structure column'''
         self._df.dropna(subset=[self.model['structure_col']], inplace=True)  # NOTE: should save operation to log
         if not len(self._df):
-            warnings.warn('ALL_NA_STRUCTURES: All structures in specified column were unrecognized, all rows dropped',
-                          RuntimeWarning)
+            warnings.warn(bleach_warnings['ALL_NA_STRUCTURES'], RuntimeWarning)
 
     def _drop_na_targets(self) -> None:
         '''Drops NA along declared target column'''
@@ -85,12 +104,10 @@ class Bleach:
         if self._target_col and run and len(self._df):  # If run and TARGET COLUMN DECLARED
             self._df.dropna(subset=[self._target_col], inplace=True)  # NOTE: should save operation to log
             if not len(self._df):
-                warnings.warn('ALL_NA_TARGETS: All targets in specified column were NA, all rows dropped',
-                              RuntimeWarning)
+                warnings.warn(bleach_warnings['ALL_NA_TARGETS'], RuntimeWarning)
 
         elif run:  # If run but not declared target
-            warnings.warn('NO_ACTIVITY_COLUMN: format_settings.remove_na_targets was set to run but no activity column \
-                was specified', RuntimeWarning)
+            warnings.warn(warnings['NA_NO_ACTIVITY_COLUMN'], UserWarning)
 
     def _build_smiles(self) -> None:
         """Creates a SMILES column in the dataset using dataset MolFile column. DROPS NA."""
@@ -190,19 +207,19 @@ class Bleach:
             pd.DataFrame: _description_
         """
         df = df.copy()
-        col_name = value_col_name
+        col_name = f'neg_log_molar_{value_col_name}'
         
         # 1. Convert to -log(M)
         if input_units == 'mixed':  # Unit column
             if units_col_name:
+                # df[col_name] = UnitConverter(df[value_col_name], df[units_col_name], naclo.mol_weights(df[mol_col_name]))
                 df = UnitConverter.df_converter(df=df, mol_col_name=mol_col_name, value_col_name=value_col_name,
                                                 units_col_name=units_col_name, output_units='-log(m)', drop_na_units=False)
             else:
                 raise ValueError('Must specify units_col_name if input_units is mixed')
         else:
             if units_col_name:
-                warnings.warn('CONFLICTING_INPUT_UNITS: Units column was specified but input units were not mixed',
-                              RuntimeWarning)
+                warnings.warn(bleach_warnings['CONFLICTING_INPUT_UNITS'], UserWarning)
             df[col_name] = UnitConverter.convert(df[value_col_name].astype(float), input_units, '-log(m)')
         
         # 2. Average
@@ -283,8 +300,7 @@ class Bleach:
             avg_flag = True
         elif method == 'remove' or (method == 'average' and not target_col_name):
             if method == 'average':
-                warnings.warn('Average duplicates was seletced but no target column was specified. Duplicates were \
-                    removed instead.', RuntimeWarning)
+                warnings.warn(bleach_warnings['DUPLICATES_NO_ACTIVITY_COLUMN'], UserWarning)
             df = stse.duplicates.remove(df, subsets=[inchi_key_col_name])  # NOTE: should save operation to log
         return df, avg_flag
     
@@ -311,8 +327,7 @@ class Bleach:
                 raise ValueError('Must specify units_col_name if input_units is mixed')
         else:
             if units_col_name:
-                warnings.warn('CONFLICTING_INPUT_UNITS: Units column was specified but input units were not mixed. Converted using input units',
-                              RuntimeWarning)
+                warnings.warn(bleach_warnings['CONFLICTING_INPUT_UNITS'], RuntimeWarning)
                 
             units_label = 'neg_log_molar' if output_units.lower() == '-log(m)' else output_units  # -log(M) may screw up datasheet characters
             df[f'{units_label}_{value_col_name}'] = UnitConverter.convert(df[value_col_name], input_units, output_units)
@@ -322,8 +337,7 @@ class Bleach:
         if self._target_units.lower() == self.model['output_units'].lower():
             return  # No change -- already in correct units
         elif not self.model['target_col']:
-            warnings.warn('OUTPUT_UNITS_CONVERSION: No target column was specified. No unit conversion was performed.',
-                          RuntimeWarning)
+            warnings.warn(bleach_warnings['OUTPUT_UNITS_CONVERSION'], UserWarning)
             return
         
         # Has already been converted to -log(m)
