@@ -1,6 +1,5 @@
 import unittest
 import copy
-from xml.etree.ElementTree import QName
 import numpy as np
 import pandas as pd
 from rdkit import Chem
@@ -330,7 +329,7 @@ class TestBleach(unittest.TestCase):
         bleach.init_structure_compute()
         bleach.chem_cleanup()
         
-        with self.assertWarns(RuntimeWarning):
+        with self.assertWarns(UserWarning):
             bleach.handle_duplicates()
         ### defaults to same as remove
         self.assertTrue(bleach.df[['SMILES', 'InchiKey', 'target']].reset_index(drop=True).equals(expected_remove))
@@ -376,7 +375,7 @@ class TestBleach(unittest.TestCase):
         bleach.init_structure_compute()
         bleach.chem_cleanup()
         
-        with self.assertWarns(RuntimeWarning):
+        with self.assertWarns(UserWarning):
             bleach.handle_duplicates()
             
         ### check pointer after (should be changed to -log(M))
@@ -448,6 +447,7 @@ class TestBleach(unittest.TestCase):
         model['target_col'] = 'target'
         
         model['input_units'] = 'mixed'
+        model['output_units'] = '-log(M)'
         model['units_col'] = 'units'
         df['units'] = [np.nan, 'nm', 'm', 'pg ml-1', 'UM', 'mM', 'M']
         
@@ -503,6 +503,7 @@ class TestBleach(unittest.TestCase):
         
         model['format_settings']['duplicate_compounds'] = 'remove'
         model['input_units'] = 'M'  # NOTE: For easy conversion factor testing
+        model['output_units'] = '-log(M)'
         model['units_col'] = 'units'
         
         ## -> -log(M) conversion
@@ -531,7 +532,7 @@ class TestBleach(unittest.TestCase):
             after['neg_log_molar_target'].to_numpy().round(decimals=4).tolist()
         )
         
-    # def test_append_columns(self):
+    def test_append_columns(self):
         model = self.default_model
         model['structure_col'] = 'SMILES'
         model['structure_type'] = 'smiles'
